@@ -8,7 +8,7 @@ use Config;
 use Inline;
 
 use Rinutils::Paths::Base qw( is_win );
-use Rinutils::Paths qw( bin_file src_file );
+use Rinutils::Paths       qw( bin_file src_file );
 
 sub import
 {
@@ -38,7 +38,7 @@ sub import
                 ( ["include"], ["rinutils/include"], [] ) ),
         CCFLAGS           => $ccflags,
         CLEAN_AFTER_BUILD => 0,
-        LIBS              => "-L$ENV{FCS_PATH} $libs",
+        LIBS              => "-L$ENV{FCS_BIN_PATH} $libs",
         @workaround_for_a_heisenbug,
         %args,
     );
@@ -56,7 +56,9 @@ sub import
 
 =cut
 
+    ## no critic
     eval "{ package $pkg; Inline->bind(\@inline_params); }";
+    ## use critic
 
     if ($@)
     {
